# colnade.dataframe

DataFrame, LazyFrame, GroupBy, JoinedDataFrame, and untyped escape hatches.

## DataFrame

::: colnade.dataframe.DataFrame

## LazyFrame

::: colnade.dataframe.LazyFrame

## GroupBy

::: colnade.dataframe.GroupBy

## LazyGroupBy

::: colnade.dataframe.LazyGroupBy

## JoinedDataFrame

::: colnade.dataframe.JoinedDataFrame

## JoinedLazyFrame

::: colnade.dataframe.JoinedLazyFrame

## UntypedDataFrame

::: colnade.dataframe.UntypedDataFrame

## UntypedLazyFrame

::: colnade.dataframe.UntypedLazyFrame
